@@ -10,7 +10,10 @@ def custom_exception_handler(exc, context):
 
     # Now add the HTTP status code to the response.
     if response is not None:
-        response.data['status_code'] = response.status_code
-        pprint(response.data)
+        try:
+            pprint(response.data)
+            response.data['status_code'] = response.status_code
+        except Exception as e:
+            pass
 
     return response
\ No newline at end of file
