@@ -8,10 +8,14 @@ class CustomPagination(PageNumberPagination):
     page_size_query_param = 'page_size'
     def get_paginated_response(self, data):
         return Response(OrderedDict([
-            ('lastPage', self.page.paginator.count),
+            ('last_page', self.page.paginator.count),
             ('count', self.page.paginator.count),
             ('current', self.page.number),
             ('next', self.get_next_link()),
             ('previous', self.get_previous_link()),
             ('results', data)
-        ]))
\ No newline at end of file
+        ]))
+    def paginate_queryset(self, queryset, request, view=None):
+        if 'no_page' in request.query_params:
+            return None
+        return super().paginate_queryset(queryset, request, view)
\ No newline at end of file
