@@ -22,12 +22,14 @@ class DefaultPrivateApiViewMixin(generics.GenericAPIView):
 
 class DefaultPrivateViewSetMixin(DefaultPrivateApiViewMixin):
 
+    def update(self, request, *args, **kwargs):
+        return super().update(request, *args, **kwargs, partial=True)
 
     def get_defaults(self):
         return {'user': self.request.user}
 
     def get_queryset(self):
-        return self.queryset.filter(**self.get_defaults())
+        return self.queryset.is_owner().filter(**self.get_defaults())
 
     def perform_create(self, serializer):
         serializer.save(**self.get_defaults())
